
package org.omegahat.DataStructures.Data;

/**
  Primitive, top-level interface for defining elementary 
  methods for data frame concepts, such as subsetting,
   indexing by variable name.
 */
public interface BasicFrameInt
        extends org.omegahat.Environment.Databases.Database
{
/**
  Return a (ordered) list of the names of the variables contained
  in this collection.
 */
public String[] getVariableNames();

 /**
    Return the number of variables contained in this frame.
  */
public long numVariables();


 /**
   Return the number of observations available in each of the variables.
   This assumes that the variables have the same number of records/observations.
  */
public long numObservations();


 /**
    Returns an array of the identifiers of the row names.
   */ 
public String[] rowNames();
public String[] rowNames(java.io.InputStream stream) throws java.io.IOException;
public String   rowName(String name, int which);

/**
 Extract the specified variable identified by name.
  */
public VariableInt getVariable(String name);

/**
 Extract the specified variable identified by name.
  */
public VariableInt addVariable(String name, VariableInt var);

}

/*
Copyright (c) 1998, 1999 The Omega Project for Statistical Computing.
     All rights reserved.

     Redistribution and use in source and binary forms, with or without
     modification, are permitted provided that the following conditions are
     met:

       Redistributions of source code must retain the above copyright notice,
       this list of conditions and the following disclaimer.

       Redistributions in binary form must reproduce the above copyright
       notice, this list of conditions and the following disclaimer in the
       documentation and/or other materials provided with the distribution.

       Neither name of the Omega Project for Statistical Computing nor the 
       names of its contributors may be used to endorse or promote products 
       derived from this software without specific prior written permission.

     THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS'' AND ANY
     EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
     MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
     SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
     SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
     PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
     INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
     STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
     THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
*/


