
package org.omegahat.DataStructures.Data.Viewers;

import java.awt.event.MouseEvent;


/**
   Handles the display of the column headers for the variables
  in a {@link DataFrameViewer DataFrameViewer}, controlling the selection of a column header item, etc.
 */
public class VariableNameRenderer  
               implements javax.swing.table.TableCellRenderer,
                          java.awt.event.MouseListener
{
/**  
  Flag indicating whether selection should be exclusive or not.
*/
protected boolean exclusiveSelection;

/**
  The column selection model of the associated table so that we can
  set its selected entries on receipt of user actions within the elements 
  of the header.
 */
javax.swing.ListSelectionModel selectionModel;

/**
  Stores the components used to render the buttons so that we do not 
  create new ones each time (and mess up the identification of buttons in the
  {@link javax.swing.ButtonGroup ButtonGroup} on a mouse event).
*/
protected org.omegahat.Environment.Utils.OrderedTable buttons;

/**
   Group constraini
 */
protected javax.swing.ButtonGroup group;

/**
  Constructor with implicit non-exclusive selection mode.
 */
public VariableNameRenderer() {
 this(false);
}

/**
  Constructor with explicit specification of selection mode.
 */
public VariableNameRenderer(boolean exclusive) {
 exclusiveSelection(exclusive);
}


public VariableNameRenderer(javax.swing.ListSelectionModel selectionModel) {
  this();
  this.selectionModel = selectionModel;
}

public VariableNameRenderer(boolean exclusive, javax.swing.ListSelectionModel selectionModel) {
  this(exclusive);
  this.selectionModel = selectionModel;
}


/**
  Create a component for the specified column with the contents given
  by <code>value</code>
 
  @param value  name of the variable being displayed in this column.
*/
public java.awt.Component  
getTableCellRendererComponent(javax.swing.JTable table,
                                 Object value, boolean isSelected, boolean hasFocus,
                                  int row, int column) 
{
 javax.swing.AbstractButton btn;
 String label = value.toString();
 if(buttons == null || column > buttons.size()-1) {
   btn = createComponent(label, table);
  if(exclusiveSelection()) {
   group().add(btn);
  }
   if(buttons == null)
      table.getTableHeader().addMouseListener(this);
   buttons().put(label, btn);
 } else {
   btn = (javax.swing.AbstractButton) buttons().get(label);
 }

 return(btn);
}

/**
 Create the actual button, or whatever to use for the specified
  column, as opposed to the
   {@link #getTableCellRendererComponent(javax.swing.JTable, Object, boolean, boolean, int, int)
    getTableCellRendererComponent()}
  method which stores it as well.
  This is intended to be overridden to provide different effects.

  @param value the name of the variable being displayed in this component.
  @param table provided so that one can get access to the
   {@link org.omegahat.DataStructures.Data.DataFrameInt DataFrameInt}
   in which the variable is located, and hence the variable.
*/
public javax.swing.AbstractButton createComponent(String value, javax.swing.JTable table) {
 if(exclusiveSelection())
  return(new javax.swing.JRadioButton(value));
 else
  return(new javax.swing.JCheckBox(value));
}


   /**
      This is invoked when the user clicks on one of the column header components, 
      and it handles toggling the selection of that component.
     */
 public  void  mouseClicked(MouseEvent e) 
  {
    int column = ((javax.swing.table.JTableHeader)e.getSource()).columnAtPoint(e.getPoint());
    javax.swing.AbstractButton btn = (javax.swing.AbstractButton)buttons().ordered().elementAt(column);

    if(btn.isEnabled() == false)
      return;

    boolean select  = !  btn.isSelected();
     btn.setSelected(select);
     if(select)
       selectionModel.addSelectionInterval(column, column);
     else
       selectionModel.removeSelectionInterval(column, column);
  }
 public  void mouseEntered(MouseEvent e) 
  {
  }
 public  void mouseExited(MouseEvent e) 
  {}
 public  void mousePressed(MouseEvent e) 
  {}
 public  void mouseReleased(MouseEvent e) 
  {}




/**
   Accessor for exclusiveSelection field
 */
public boolean exclusiveSelection()
{
   return(exclusiveSelection);
}
/**
   Accessor for setting the {@link exclusiveSelection exclusiveSelection} field
 */
public boolean exclusiveSelection(boolean value)
{
   exclusiveSelection = value;
   return(exclusiveSelection());
}



/**
   Accessor for buttons field
 */
public org.omegahat.Environment.Utils.OrderedTable buttons()
{
  if(buttons == null) {
   buttons(new org.omegahat.Environment.Utils.OrderedTable(3));
  }
  return(buttons);
}

/**
   Accessor for setting buttons field
 */

public org.omegahat.Environment.Utils.OrderedTable buttons(org.omegahat.Environment.Utils.OrderedTable value)
{
   buttons = value;
  return(buttons);
}





public javax.swing.ButtonGroup group()
{
 if(group == null)
   group = new javax.swing.ButtonGroup();

 return(group);
}

public javax.swing.ButtonGroup group(javax.swing.ButtonGroup value)
{
   group = value;
  return(group);
}

}

/*
Copyright (c) 1998 1999, The Omega Project for Statistical Computing.
     All rights reserved.

     Redistribution and use in source and binary forms, with or without
     modification, are permitted provided that the following conditions are
     met:

       Redistributions of source code must retain the above copyright notice,
       this list of conditions and the following disclaimer.

       Redistributions in binary form must reproduce the above copyright
       notice, this list of conditions and the following disclaimer in the
       documentation and/or other materials provided with the distribution.

       Neither name of the Omega Project for Statistical Computing nor the 
       names of its contributors may be used to endorse or promote products 
       derived from this software without specific prior written permission.

     THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS'' AND ANY
     EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
     MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
     SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
     SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
     PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
     INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
     STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
     THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 

*/


